@@ -1,4 +1,6 @@
 import logging
+from builtins import RuntimeError
+from contextlib import suppress
 
 import psutil
 from s3transfer import MB
@@ -7,8 +9,10 @@ logger = logging.getLogger(__name__)
 
 
 def log_freq():
-    freq = psutil.cpu_freq()
-    logger.info(f"CPU freq is {freq}")
+    # due to RuntimeError: CallNtPowerInformation syscall failed
+    with suppress(RuntimeError):
+        freq = psutil.cpu_freq()
+        logger.info(f"CPU freq is {freq}")
 
 
 def log_usage():
